# Welcome to The Arcade Library!

<p align="center">
    <a href="https://img.shields.io/pypi/l/arcade">
        <img alt="MIT License" title="MIT License" src="https://img.shields.io/pypi/l/arcade">
    </a>
    <a href="http://makeapullrequest.com">
        <img alt="Pull Requests Welcome" title="Pull Requests Welcome" src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat" />
    </a>
    <a href="http://www.firsttimersonly.com/">
        <img alt="First Timers Friendly" title="First Timers Friendly" src="https://img.shields.io/badge/first--timers--only-friendly-blue.svg" />
    </a>
</p>

Arcade is an easy-to-learn Python library for creating 2D video games.
It is ideal for beginning programmers or programmers who want to create
2D games without learning a complex framework.

[pyglet]: https://github.com/pyglet/pyglet
[Games Made with Arcade]: https://api.arcade.academy/en/latest/community/games/sample_games.html
Arcade is built on top of [pyglet][] and OpenGL. See [Games Made with Arcade][]
for example game jam entries and more.

[Arcade Discord Server]: https://discord.gg/ZjGDqMp

<p align="center">
    <a href="https://img.shields.io/pypi/dm/arcade">
        <img alt="PyPI - Downloads" title="PyPI - Downloads" src="https://img.shields.io/pypi/dm/arcade">
    </a>
    <a href="https://img.shields.io/github/commit-activity/m/pythonarcade/arcade">
        <img alt="GitHub Commit Activity" title="GitHub Commit Activity" src="https://img.shields.io/github/commit-activity/m/pythonarcade/arcade">
    </a>
    <a href="https://img.shields.io/github/contributors/pythonarcade/arcade">
        <img alt="GitHub Contributors" title="GitHub Contributors" src="https://img.shields.io/github/contributors/pythonarcade/arcade">
    </a>
    <a href="https://img.shields.io/github/stars/pythonarcade/arcade">
        <img alt="GitHub Stars" title="GitHub Stars" src="https://img.shields.io/github/stars/pythonarcade/arcade">
    </a>
</p>

## Stable Documentation

Read the stable documentation at https://api.arcade.academy.

## Development Previews

Preview the next release at https://api.arcade.academy/en/development/.

## Citation

```
    @Online{PythonArcade,
       author = {Paul Vincent Craven},
       title = {Easy to use Python library for creating 2D Arcade games.},
       date = {2023-01-01},
       publisher = {GitHub},
       journal = {GitHub repository},
       howpublished = {\url{https://github.com/pythonarcade/arcade}},
       commit = {<insert hash if needed>}
    }
```

## Contact the Maintainers

The best way to contact and chat with the maintainers is on the
[Arcade Discord Server][].

paul@cravenfamily.com
